==> 0.0.56.tar.gz: lib/widget/dialog/custom_dialog_selection.dart <==

import '../../common/values/colors.dart';
import '../../common/values/sizes.dart';
import '../../common/values/styles.dart';
import '../custom/custom_icon.dart';
import '../custom/spaces.dart';
import '../text/custom_text_header_medium_field.dart';
import '../text/custom_text_medium_field.dart';
import 'package:flutter/material.dart';

class CustomDialogSelection extends StatelessWidget {
  final String? title, code, content;
  final String negativeBtnText;
  final GestureTapCallback positiveBtnPressed;
  final Widget? iconWarning;
  final Color? colorWarning;

  CustomDialogSelection({
    required this.title,
    required this.negativeBtnText,
    required this.positiveBtnPressed,
    this.content,
    this.iconWarning,
    this.code,
    this.colorWarning = SharingColors.ErrorColor,
  });

  @override
  Widget build(BuildContext context) {
    return Dialog(
      elevation: 0,
      backgroundColor: Colors.transparent,
      child: _buildDialogContent(context),
    );
  }

  Widget _buildDialogContent(BuildContext context) {
    return Stack(
      alignment: Alignment.topCenter,
      children: <Widget>[
        Container(
          margin:
              EdgeInsets.only(top: 40), // to push the box half way below circle
          decoration: BoxDecoration(
              color: Colors.white, borderRadius: BorderRadius.circular(10)),
          child: Column(
            mainAxisSize: MainAxisSize.min,
            children: <Widget>[
              Container(
                  width: Sizes.width(context),
                  height: Sizes.HEIGHT_60,
                  decoration: BoxDecoration(
                    color: colorWarning,
                    borderRadius: BorderRadius.only(
                        topLeft: Radius.circular(10),
                        topRight: Radius.circular(10)),
                  ),
                  child: iconWarning ??
                      CustomIcon(
                          icon: Icons.warning,
                          color: SharingColors.WarningColor,
                          size: 36)),
              SpaceH10(),
              CustomTextHeaderMediumField(
                label: title,
                align: TextAlign.center,
              ),
              SpaceH10(),
              code != null
                  ? Padding(
                      padding: const EdgeInsets.symmetric(horizontal: 8),
                      child: CustomTextMediumField(
                        label: code,
                        color: SharingColors.WarningColor,
                        align: TextAlign.center,
                        maxLine: 4,
                      ),
                    )
                  : Container(),
              SpaceH10(),
              content != null
                  ? Padding(
                      padding: const EdgeInsets.symmetric(horizontal: 8),
                      child: CustomTextMediumField(
                        label: content,
                        align: TextAlign.center,
                        maxLine: 4,
                      ),
                    )
                  : Container(),
              SpaceH10(),
              Row(
                mainAxisSize: MainAxisSize.max,
                mainAxisAlignment: MainAxisAlignment.spaceEvenly,
                children: <Widget>[
                  Expanded(
                    flex: 1,
                    child: TextButton(
                      child: Text(
                        negativeBtnText,
                        style: Styles.customTextMediumStyle(
                            color: Theme.of(context).colorScheme.secondary),
                      ),
                      onPressed: () => Navigator.of(context).pop(),
                    ),
                  )
                ],
              ),
            ],
          ),
        ),
      ],
    );
  }
}

==> 0.0.64.tar.gz: lib/widget/dialog/custom_dialog_selection.dart <==

import '../../common/values/colors.dart';
import '../../common/values/sizes.dart';
import '../../common/values/styles.dart';
import '../custom/custom_icon.dart';
import '../custom/spaces.dart';
import '../text/custom_text_header_medium_field.dart';
import '../text/custom_text_medium_field.dart';
import 'package:flutter/material.dart';

class CustomDialogSelection extends StatelessWidget {
  final String? title, code, content;
  final String negativeBtnText;
  final GestureTapCallback positiveBtnPressed;
  final Widget? iconWarning;
  final Color? colorWarning;

  CustomDialogSelection({
    required this.title,
    required this.negativeBtnText,
    required this.positiveBtnPressed,
    this.content,
    this.iconWarning,
    this.code,
    this.colorWarning = SharingColors.ErrorColor,
  });

  @override
  Widget build(BuildContext context) {
    return Dialog(
      elevation: 0,
      backgroundColor: Colors.transparent,
      child: _buildDialogContent(context),
    );
  }

  Widget _buildDialogContent(BuildContext context) {
    return Stack(
      alignment: Alignment.topCenter,
      children: <Widget>[
        Container(
          margin:
              EdgeInsets.only(top: Sizes.PADDING_40), // to push the box half way below circle
          decoration: BoxDecoration(
              color: Colors.white, borderRadius: BorderRadius.circular(10)),
          child: Column(
            mainAxisSize: MainAxisSize.min,
            children: <Widget>[
              Container(
                  width: Sizes.width(context),
                  height: Sizes.HEIGHT_60,
                  decoration: BoxDecoration(
                    color: colorWarning,
                    borderRadius: BorderRadius.only(
                        topLeft: Radius.circular(10),
                        topRight: Radius.circular(10)),
                  ),
                  child: iconWarning ??
                      CustomIcon(
                          icon: Icons.warning,
                          color: SharingColors.WarningColor,
                          size: Sizes.ICON_SIZE_32)),
              SpaceH10(),
              CustomTextHeaderMediumField(
                label: title,
                align: TextAlign.center,
              ),
              SpaceH10(),
              code != null
                  ? Padding(
                      padding: EdgeInsets.symmetric(horizontal: Sizes.PADDING_8),
                      child: CustomTextMediumField(
                        label: code,
                        color: SharingColors.WarningColor,
                        align: TextAlign.center,
                        maxLine: 4,
                      ),
                    )
                  : Container(),
              SpaceH10(),
              content != null
                  ? Padding(
                      padding: EdgeInsets.symmetric(horizontal: Sizes.PADDING_12),
                      child: CustomTextMediumField(
                        label: content,
                        align: TextAlign.center,
                        maxLine: 4,
                      ),
                    )
                  : Container(),
              SpaceH10(),
              Row(
                mainAxisSize: MainAxisSize.max,
                mainAxisAlignment: MainAxisAlignment.spaceEvenly,
                children: <Widget>[
                  Expanded(
                    flex: 1,
                    child: TextButton(
                      child: Text(
                        negativeBtnText,
                        style: Styles.customTextMediumStyle(
                            color: Theme.of(context).colorScheme.secondary),
                      ),
                      onPressed: () => Navigator.of(context).pop(),
                    ),
                  )
                ],
              ),
            ],
          ),
        ),
      ],
    );
  }
}
